@@ -1,14 +1,15 @@
-#' Spatialize trajectories.
+#' Length normalize trajectories.
 #' 
 #' Re-represent each trajectory spatially using a constant number of points so 
 #' that adjacent points on the trajectory become equidistant to each other.
 #' 
-#' \code{mt_spatialize} is used to emphasize the trajectories' shape. Usually, 
-#' the vast majority of points of a raw or a time-normalized trajectory lie
-#' close to the start and end point. \code{mt_spatialize} re-distributes these
-#' points so that the spatial distribution is uniform across the entire
-#' trajectory. \code{mt_spatialize} is mainly used to improve the results of
-#' clustering (in particular \link{mt_cluster}) and visualization.
+#' \code{mt_length_normalize} is used to emphasize the trajectories' shape.
+#' Usually, the vast majority of points of a raw or a time-normalized trajectory
+#' lie close to the start and end point. \code{mt_length_normalize}
+#' re-distributes these points so that the spatial distribution is uniform
+#' across the entire trajectory. \code{mt_length_normalize} is mainly used to
+#' improve the results of clustering (in particular \link{mt_cluster}) and
+#' visualization.
 #'
 #' @inheritParams mt_time_normalize
 #' @param dimensions a character string specifying which trajectory variables 
@@ -20,13 +21,13 @@
 #'   trajectories. Alternatively, a vector of integers can provided that specify
 #'   the number of points for each trajectory individually.
 #'
-#' @return A mousetrap data object (see \link{mt_example}) with an additional 
-#'   array (by default called \code{sp_trajectories}) containing the spatialized
-#'   trajectories. If a trajectory array was provided directly as \code{data}, 
-#'   only the spatialized trajectories will be returned.
+#' @return A mousetrap data object (see \link{mt_example}) with an additional
+#'   array (by default called \code{ln_trajectories}) containing the length
+#'   normalized trajectories. If a trajectory array was provided directly as
+#'   \code{data}, only the length normalized trajectories will be returned.
 #'
 #' @examples
-#' KH2017 <- mt_spatialize(data=KH2017,
+#' KH2017 <- mt_length_normalize(data=KH2017,
 #'   dimensions = c('xpos','ypos'),
 #'   n_points = 20)
 #'
@@ -36,13 +37,13 @@
 #' Jonas M. B. Haslbeck
 #'
 #' @export
-
-mt_spatialize = function(data,
-                         use = 'trajectories',
-                         dimensions = c('xpos', 'ypos'),
-                         save_as = 'sp_trajectories',
-                         n_points = 20
-                         ){
+mt_length_normalize <- function(
+  data,
+  use = 'trajectories',
+  dimensions = c('xpos', 'ypos'),
+  save_as = 'ln_trajectories',
+  n_points = 20
+  ){
 
   # Extract trajectories
   trajectories <- extract_data(data,use)
@@ -55,7 +56,7 @@ mt_spatialize = function(data,
     stop('Not all dimensions exist.')
   }
 
-  # Spatialize trajectories
+  # Length normalize trajectories
   if (length(dimensions) == 2) {
     if (nrow(trajectories) == 1) {
       # Cover special case of single trajectory
@@ -101,6 +102,69 @@ mt_spatialize = function(data,
   return(create_results(data=data, results=result, use=use, save_as=save_as))
 }
 
+
+#' Spatialize trajectories.
+#' 
+#' Re-represent each trajectory spatially using a constant number of points so
+#' that adjacent points on the trajectory become equidistant to each other.
+#' Please note that this function is \strong{deprecated} and that
+#' \link{mt_length_normalize} should be used instead.
+#' 
+#' \code{mt_spatialize} is used to emphasize the trajectories' shape. Usually, 
+#' the vast majority of points of a raw or a time-normalized trajectory lie
+#' close to the start and end point. \code{mt_spatialize} re-distributes these
+#' points so that the spatial distribution is uniform across the entire
+#' trajectory. \code{mt_spatialize} is mainly used to improve the results of
+#' clustering (in particular \link{mt_cluster}) and visualization.
+#'
+#' @inheritParams mt_length_normalize
+#'
+#' @return A mousetrap data object (see \link{mt_example}) with an additional
+#'   array containing the spatialized trajectories. If a trajectory array was
+#'   provided directly as \code{data}, only the spatialized trajectories will be
+#'   returned.
+#'
+#' @examples
+#' \dontrun{
+#' KH2017 <- mt_spatialize(data=KH2017,
+#'   dimensions = c('xpos','ypos'),
+#'   n_points = 20)
+#' }
+#'
+#' @author
+#' Dirk U. Wulff
+#'
+#' Jonas M. B. Haslbeck
+#'
+#' @export
+mt_spatialize <- function(data,
+                         use = 'trajectories',
+                         dimensions = c('xpos', 'ypos'),
+                         save_as = 'sp_trajectories',
+                         n_points = 20
+){
+  
+  .Deprecated("mt_length_normalize")
+  
+  if(save_as == "sp_trajectories"){
+    warning(
+      "The save_as argument in mt_spatialize has been left at sp_trajectories. ",
+      "Please note that, due to the replacement of mt_spatialize with mt_length_normalize, ",
+      "functions working with length normalized trajectories will now ",
+      " - by default (if the use argument is not specified explicitly) - ",
+      "expect them to be called ln_trajectories instead of sp_trajectories."
+      )
+  }
+  
+  return(
+    mt_length_normalize(
+      data = data, use = use, dimensions = dimensions,
+      save_as = save_as, n_points = n_points
+    )
+  )
+}
+
+
 # Spatialize trajectories to long (internal function)
 mt_spatialize_tolong <- function(data,
                                  use='trajectories',
